Fundamental Electronic Definitions
==================================

Read more in *The Art of Electronics* by Paul Horowitz and Winfield Hill.

There are some important definitions we must account for in terms of analysing the data of our simulations.

.. list-table:: Fundamental Definitions
   :widths: 25 50 50
   :header-rows: 1

   * - Term
     - Definition
     - Unit
   * - Voltage :math:`V`
     - The work on electric charges.
     - It takes :math:`1J` Joule to move :math:`1C` Coulomb of charge through a potential of :math:`1V` volt.
   * - Current :math:`i`
     - The rate of the flow of electric charge past a point.
     - :math:`1A` amp defines the movement of the above :math:`1C` Coulomb of charge flows in :math:`1s` second.
   * - Power :math:`W`
     - For a differential of time, this is the rate energy consumed for that slice of time.
     - :math:`W = VI` Watt defines the rate of energy flow of the above :math:`1J` Joule in :math:`1s` second.
   * - Energy :math:`J`
     - Applied power throughout a slice of time.
     - :math:`J = Ws` Joule is equal to :math:`1W` Watt of power flowing throughout :math:`1s` second.


Currents occur by placing a voltage through a device, and the rate of the current, hence the rate of the power consumption is dependent on the channel *impedance*. Now, this has an important effect on microwave engineering and system design.
